@@ -59,15 +59,13 @@ mi.binary <- function( formula, data = NULL, start = NULL, n.iter = 100,
   tt <- terms(bglm.imp)
   Terms <- delete.response(tt)
   m <- model.frame(Terms, data=data,  xlev = bglm.imp$xlevels)
-  X <- as.matrix(model.matrix(Terms, m, contrasts.arg = bglm.imp$contrasts)[,-1])
+  X <- as.matrix(model.matrix(Terms, m, contrasts.arg = bglm.imp$contrasts))
 ############################
-  determ.pred <- predict(bglm.imp, newdata = data, type = "response")
+   determ.pred <- predict(bglm.imp, newdata = data, type = "response")
   if(n.mis>0){
     if (draw.from.beta) {
-        sim.bglm.imp <- sim(bglm.imp, 1)
-        prob.pred <- invlogit(
-          tcrossprod(
-            as.matrix(cbind((X[mis, 1, drop=FALSE]*0+1), X[mis,,drop=FALSE])), sim.bglm.imp$coef))
+        sim.coef  <- sim(bglm.imp,1)$coef
+        prob.pred <- invlogit(tcrossprod(X[mis,,drop=FALSE], sim.coef))
         random.temp <- rbinom(n.mis, 1, prob.pred)
     }
     else {
